@@ -5,7 +5,7 @@ use warnings;
 package Dist::Iller;
 
 # ABSTRACT: A Dist::Zilla & Pod::Weaver preprocessor
-our $VERSION = '0.1402';
+our $VERSION = '0.1403';
 
 use Dist::Iller::Elk;
 use Types::Standard qw/Map Str ConsumerOf/;
@@ -82,6 +82,9 @@ sub parse {
             }
         }
     }
+    if($self->get_doc('cpanfile') && $self->get_doc('dist')) {
+        $self->get_doc('cpanfile')->merge_prereqs($self->get_doc('dist')->all_prereqs);
+    }
 }
 
 sub generate_files {
@@ -110,20 +113,20 @@ Dist::Iller - A Dist::Zilla & Pod::Weaver preprocessor
 
 =begin HTML
 
-<p><img src="https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg" alt="Requires Perl 5.10.1+" /> <a href="https://travis-ci.org/Csson/p5-Dist-Iller"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-84.4%-orange.svg" alt="coverage 84.4%" /></p>
+<p><img src="https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg" alt="Requires Perl 5.10.1+" /> <a href="https://travis-ci.org/Csson/p5-Dist-Iller"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-82.0%-orange.svg" alt="coverage 82.0%" /></p>
 
 =end HTML
 
 
 =begin markdown
 
-![Requires Perl 5.10.1+](https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Dist-Iller.svg?branch=master)](https://travis-ci.org/Csson/p5-Dist-Iller) ![coverage 84.4%](https://img.shields.io/badge/coverage-84.4%-orange.svg)
+![Requires Perl 5.10.1+](https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Dist-Iller.svg?branch=master)](https://travis-ci.org/Csson/p5-Dist-Iller) ![coverage 82.0%](https://img.shields.io/badge/coverage-82.0%-orange.svg)
 
 =end markdown
 
 =head1 VERSION
 
-Version 0.1402, released 2016-02-07.
+Version 0.1403, released 2016-02-10.
 
 =head1 SYNOPSIS
 
